
namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using Eco.Gameplay.Blocks;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Economy;
    using Eco.Gameplay.Housing;
    using Eco.Gameplay.Interactions;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Minimap;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Property;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Gameplay.Pipes.LiquidComponents;
    using Eco.Gameplay.Pipes.Gases;
    using Eco.Gameplay.Systems.Tooltip;
    using Eco.Shared;
    using Eco.Shared.Math;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Shared.Items;
    using Eco.Gameplay.Pipes;
    using Eco.World.Blocks;

    public partial class BigStorageChestObject :
            WorldObject
    {
        public override string FriendlyName { get { return "Big Storage Chest"; } }


        protected override void Initialize()
        {
            this.GetComponent<MinimapComponent>().Initialize("Storage");

            var storage = this.GetComponent<PublicStorageComponent>();
            storage.Initialize(32);
            storage.Storage.AddRestriction(new NotCarriedRestriction()); // can't store block or large items


        }

        public override void Destroy()
        {
            base.Destroy();
        }

    }
    [Serialized]
    public class BigStorageChestItem : WorldObjectItem<BigStorageChestObject>
    {
        public override string FriendlyName { get { return "Big Storage Chest"; } }
        public override string Description { get { return "A container you can store items in."; } }


    }

    [RequiresSkill(typeof(BasicCraftingSkill), 4)]
    public class BigStorageChestRecipe : Recipe
    {
        public BigStorageChestRecipe()
        {
            this.Products = new CraftingElement[]
            {
            new CraftingElement<BigStorageChestItem>(),
            };
            this.Ingredients = new CraftingElement[]
            {
            new CraftingElement<LumberItem>(typeof(BasicCraftingEfficiencySkill), 10, BasicCraftingEfficiencySkill.MultiplicativeStrategy),
            new CraftingElement<IronIngotItem>(typeof(BasicCraftingEfficiencySkill), 10, BasicCraftingEfficiencySkill.MultiplicativeStrategy),
            }; SkillModifiedValue value = new SkillModifiedValue(2, BasicCraftingSpeedSkill.MultiplicativeStrategy, typeof(BasicCraftingSpeedSkill), Localizer.Do("craft time"));
            SkillModifiedValueManager.AddBenefitForObject(typeof(BigStorageChestRecipe), Item.Get<BigStorageChestItem>().UILink(), value);
            SkillModifiedValueManager.AddSkillBenefit(Item.Get<BigStorageChestItem>().UILink(), value);
            this.CraftMinutes = value;

            this.Initialize("Big Storage Chest", typeof(BigStorageChestRecipe));
            CraftingComponent.AddRecipe(typeof(CarpentryTableObject), this);
        }
    }
}